@@ -1,4 +1,4 @@
-//  $Id: irr.cc,v 4.11.2.3 2004/07/30 10:58:11 katie Exp $
+//  $Id: irr.cc,v 4.12.2.1 2006/06/09 17:59:12 shane Exp $
 // Copyright (c) 2001,2002                        RIPE NCC
 //
 // All Rights Reserved
@@ -300,7 +300,9 @@ void IRR::initCache(const char *fname) {
 	    }      
 	 } else
 	    delete o;
-  }
+      } else
+        cerr << "WARNING: could not identify cache object found in cache-file \""
+             << fname << "\"\n" << objectText << endl;
    }
 }
 
